HookAction

Enum HookAction 

pub enum HookAction {
    Replace {
        line: String,
        cursor: usize,
    },
    InsertSpace {
        line: String,
        cursor: usize,
    },
}
Outcome of a hook call — what the shell adapter should do to its buffer.

line is the full new buffer text and cursor is the new cursor position in bytes from the start of line. Shells are expected to replace their buffer and cursor with these values atomically.

Variants



Replace

The token at the cursor expanded; shell should replace the buffer.

Fields

line: String
cursor: usize


InsertSpace

No expansion happened; shell should just insert a literal space at the cursor (the conventional trigger fallback).

Fields

line: String
cursor: usize