Module sanitize

Module sanitize 

Functions

double_quote_escape
Map a character to its double-quoted string escape sequence.
is_deceptive_unicode
Returns true if c is a Unicode visual-deception character.
is_nu_drop_char
Returns true if c should be silently dropped when building a Nu double-quoted string ("..." or ^"...").
is_unicode_line_separator
Returns true if c is a Unicode line or paragraph separator.
is_unsafe_for_display
Returns true if c should be removed before printing to a terminal.
sanitize_for_display
Strip characters unsafe for terminal display from a string.
sanitize_multiline_for_display
Strip characters unsafe for terminal display, preserving newlines and tabs.