Constants
- RUNEX_
INIT_ MARKER - Marker comment written into rc files to enable idempotent init.
Functions
- default_
config_ content - Minimal config template written by
runex init. - integration_
line - The single line appended to the shell rc file.
- rc_
file_ for - The rc file path for a given shell (best-effort; may not exist yet).