Functions
- double_
quote_ escape - Map a character to its double-quoted string escape sequence.
- is_
deceptive_ unicode - Returns true if
cis a Unicode visual-deception character. - is_
nu_ drop_ char - Returns true if
cshould be silently dropped when building a Nu double-quoted string ("..."or^"..."). - is_
unicode_ line_ separator - Returns true if
cis a Unicode line or paragraph separator. - is_
unsafe_ for_ display - Returns true if
cshould be removed before printing to a terminal. - sanitize_
for_ display - Strip characters unsafe for terminal display from a string.
- sanitize_
multiline_ for_ display - Strip characters unsafe for terminal display, preserving newlines and tabs.